@@ -261,7 +261,8 @@ avi_read_video (AviFile    *avi_file,
     {
       /* ja:メモリ */
       g_memmove (buffer,
-        (guint8 *)avi_memory_get_data (avi_file->avi_memory) + offset, size);
+        (const guint8 *)avi_memory_get_data (avi_file->avi_memory) + offset,
+        size);
     }
   else
     {
