@@ -17,7 +17,7 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "aviclip.h"
-#include "pixbuf.h"
+#include "misc/pixbuf.h"
 #ifdef G_OS_WIN32
 # include <gdk/gdkwin32.h>
 # include <tchar.h>
@@ -224,7 +224,7 @@ avi_clip_clear_func (GtkClipboard *clipboard,
 
   clip_data = user_data;
   g_free (clip_data->scenario);
-  gdk_pixbuf_unref (clip_data->pixbuf);
+  g_object_unref (clip_data->pixbuf);
   g_free (clip_data);
 # else /* not GTK_CHECK_VERSION(2,6,0) */
   g_free (user_data);
