@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,6 +36,15 @@ avi_init (void)
 gboolean
 avi_exit (void)
 {
+  if (avi_lang)
+    {
+      gint i;
+
+      for (i = 0; avi_lang[i].name; i++)
+        g_free ((gpointer)avi_lang[i].name);
+      g_free (avi_lang);
+      avi_lang = NULL;
+    }
   return icm_exit () & acm_exit ();
 }
 
@@ -49,7 +58,7 @@ avi_exit (void)
     avi_edit,AVI編集ハンドル
          RET,Rate                                                           */
 guint32
-avi_get_rate (AviEdit *avi_edit)
+avi_edit_get_rate (AviEdit *avi_edit)
 {
   return avi_edit ? avi_edit->rate : 0;
 }
@@ -59,7 +68,7 @@ avi_get_rate (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,Scale                                                          */
 guint32
-avi_get_scale (AviEdit *avi_edit)
+avi_edit_get_scale (AviEdit *avi_edit)
 {
   return avi_edit ? avi_edit->scale : 0;
 }
@@ -69,7 +78,7 @@ avi_get_scale (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,優先度                                                         */
 guint16
-avi_get_priority (AviEdit *avi_edit)
+avi_edit_get_priority (AviEdit *avi_edit)
 {
   return avi_edit ? avi_edit->priority : 0;
 }
@@ -79,7 +88,7 @@ avi_get_priority (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,言語                                                           */
 guint16
-avi_get_language (AviEdit *avi_edit)
+avi_edit_get_language (AviEdit *avi_edit)
 {
   return avi_edit ? avi_edit->language : 0;
 }
@@ -89,7 +98,7 @@ avi_get_language (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,名前                                                           */
 const gchar *
-avi_get_name (AviEdit *avi_edit)
+avi_edit_get_name (AviEdit *avi_edit)
 {
   return avi_edit ? avi_edit->name : NULL;
 }
@@ -99,7 +108,7 @@ avi_get_name (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,幅,0:エラー                                                    */
 gint32
-avi_get_width (AviEdit *avi_edit)
+avi_edit_get_width (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->bmih ? bmih_get_width (avi_edit->bmih) : 0;
 }
@@ -109,7 +118,7 @@ avi_get_width (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,高さ,0:エラー                                                  */
 gint32
-avi_get_height (AviEdit *avi_edit)
+avi_edit_get_height (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->bmih ? bmih_get_height (avi_edit->bmih) : 0;
 }
@@ -119,7 +128,7 @@ avi_get_height (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,色数,0:エラー                                                  */
 guint16
-avi_get_bit_count (AviEdit *avi_edit)
+avi_edit_get_bit_count (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->bmih ? bmih_get_bit_count (avi_edit->bmih) : 0;
 }
@@ -129,7 +138,7 @@ avi_get_bit_count (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,X解像度,-1:エラー                                              */
 gint32
-avi_get_x_pixels_per_meter (AviEdit *avi_edit)
+avi_edit_get_x_pixels_per_meter (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->bmih
                         ? bmih_get_x_pixels_per_meter (avi_edit->bmih) : -1;
@@ -140,7 +149,7 @@ avi_get_x_pixels_per_meter (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,Y解像度,-1:エラー                                              */
 gint32
-avi_get_y_pixels_per_meter (AviEdit *avi_edit)
+avi_edit_get_y_pixels_per_meter (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->bmih
                         ? bmih_get_y_pixels_per_meter (avi_edit->bmih) : -1;
@@ -151,7 +160,7 @@ avi_get_y_pixels_per_meter (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,レート,0:エラー                                                */
 guint32
-avi_get_samples_per_sec (AviEdit *avi_edit)
+avi_edit_get_samples_per_sec (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->wfx
                                 ? wfx_get_samples_per_sec (avi_edit->wfx) : 0;
@@ -162,7 +171,7 @@ avi_get_samples_per_sec (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,チャンネル,0:エラー                                            */
 guint16
-avi_get_channels (AviEdit *avi_edit)
+avi_edit_get_channels (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->wfx ? wfx_get_channels (avi_edit->wfx) : 0;
 }
@@ -172,7 +181,7 @@ avi_get_channels (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,ビット,0:エラー                                                */
 guint16
-avi_get_bits_per_sample (AviEdit *avi_edit)
+avi_edit_get_bits_per_sample (AviEdit *avi_edit)
 {
   return avi_edit && avi_edit->wfx
                                 ? wfx_get_bits_per_sample (avi_edit->wfx) : 0;
@@ -183,8 +192,8 @@ avi_get_bits_per_sample (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
         rate,Rate                                                           */
 void
-avi_set_rate (AviEdit *avi_edit,
-              guint32  rate)
+avi_edit_set_rate (AviEdit       *avi_edit,
+                   const guint32  rate)
 {
   if (avi_edit && rate > 0)
     avi_edit->rate = rate;
@@ -195,8 +204,8 @@ avi_set_rate (AviEdit *avi_edit,
     avi_edit,AVI編集ハンドル
        scale,Scale                                                          */
 void
-avi_set_scale (AviEdit *avi_edit,
-               guint32  scale)
+avi_edit_set_scale (AviEdit       *avi_edit,
+                    const guint32  scale)
 {
   if (avi_edit && scale > 0)
     avi_edit->scale = scale;
@@ -207,8 +216,8 @@ avi_set_scale (AviEdit *avi_edit,
     avi_edit,AVI編集ハンドル
     priority,優先度                                                         */
 void
-avi_set_priority (AviEdit *avi_edit,
-                  guint16  priority)
+avi_edit_set_priority (AviEdit       *avi_edit,
+                       const guint16  priority)
 {
   if (avi_edit)
     avi_edit->priority = priority;
@@ -219,8 +228,8 @@ avi_set_priority (AviEdit *avi_edit,
     avi_edit,AVI編集ハンドル
     language,言語                                                           */
 void
-avi_set_language (AviEdit *avi_edit,
-                  guint16  language)
+avi_edit_set_language (AviEdit       *avi_edit,
+                       const guint16  language)
 {
   if (avi_edit)
     avi_edit->language = language;
@@ -231,8 +240,8 @@ avi_set_language (AviEdit *avi_edit,
     avi_edit,AVI編集ハンドル
         name,名前                                                           */
 void
-avi_set_name (AviEdit     *avi_edit,
-              const gchar *name)
+avi_edit_set_name (AviEdit     *avi_edit,
+                   const gchar *name)
 {
   if (avi_edit)
     {
@@ -246,8 +255,8 @@ avi_set_name (AviEdit     *avi_edit,
     avi_edit,AVI編集ハンドル
        width,幅                                                             */
 void
-avi_set_width (AviEdit *avi_edit,
-               gint32   width)
+avi_edit_set_width (AviEdit      *avi_edit,
+                    const gint32  width)
 {
   if (avi_edit && avi_edit->bmih)
     {
@@ -261,8 +270,8 @@ avi_set_width (AviEdit *avi_edit,
     avi_edit,AVI編集ハンドル
       height,高さ                                                           */
 void
-avi_set_height (AviEdit *avi_edit,
-                gint32   height)
+avi_edit_set_height (AviEdit      *avi_edit,
+                     const gint32  height)
 {
   if (avi_edit && avi_edit->bmih)
     {
@@ -276,8 +285,8 @@ avi_set_height (AviEdit *avi_edit,
      avi_edit,AVI編集ハンドル
     bit_count,色数                                                          */
 void
-avi_set_bit_count (AviEdit *avi_edit,
-                   guint16  bit_count)
+avi_edit_set_bit_count (AviEdit       *avi_edit,
+                        const guint16  bit_count)
 {
   if (avi_edit && avi_edit->bmih)
     {
@@ -292,8 +301,8 @@ avi_set_bit_count (AviEdit *avi_edit,
               avi_edit,AVI編集ハンドル
     x_pixels_per_meter,X解像度                                              */
 void
-avi_set_x_pixels_per_meter (AviEdit *avi_edit,
-                            gint32   x_pixels_per_meter)
+avi_edit_set_x_pixels_per_meter (AviEdit      *avi_edit,
+                                 const gint32  x_pixels_per_meter)
 {
   if (avi_edit && avi_edit->bmih)
     bmih_set_x_pixels_per_meter (avi_edit->bmih, x_pixels_per_meter);
@@ -304,8 +313,8 @@ avi_set_x_pixels_per_meter (AviEdit *avi_edit,
               avi_edit,AVI編集ハンドル
     y_pixels_per_meter,Y解像度                                              */
 void
-avi_set_y_pixels_per_meter (AviEdit *avi_edit,
-                            gint32   y_pixels_per_meter)
+avi_edit_set_y_pixels_per_meter (AviEdit      *avi_edit,
+                                 const gint32  y_pixels_per_meter)
 {
   if (avi_edit && avi_edit->bmih)
     bmih_set_y_pixels_per_meter (avi_edit->bmih, y_pixels_per_meter);
@@ -316,8 +325,8 @@ avi_set_y_pixels_per_meter (AviEdit *avi_edit,
            avi_edit,AVI編集ハンドル
     samples_per_sec,レート                                                  */
 void
-avi_set_samples_per_sec (AviEdit *avi_edit,
-                         guint32  samples_per_sec)
+avi_edit_set_samples_per_sec (AviEdit       *avi_edit,
+                              const guint32  samples_per_sec)
 {
   if (avi_edit && avi_edit->wfx)
     {
@@ -325,8 +334,8 @@ avi_set_samples_per_sec (AviEdit *avi_edit,
       wfx_set_average_bytes_per_sec (avi_edit->wfx, samples_per_sec
                             * (wfx_get_channels (avi_edit->wfx)
                             * wfx_get_bits_per_sample (avi_edit->wfx) / 8));
-      avi_set_rate (avi_edit, samples_per_sec);
-      avi_set_scale (avi_edit, 1);
+      avi_edit_set_rate (avi_edit, samples_per_sec);
+      avi_edit_set_scale (avi_edit, 1);
     }
 }
 
@@ -335,8 +344,8 @@ avi_set_samples_per_sec (AviEdit *avi_edit,
     avi_edit,AVI編集ハンドル
     channels,チャンネル                                                     */
 void
-avi_set_channels (AviEdit *avi_edit,
-                  guint16  channels)
+avi_edit_set_channels (AviEdit       *avi_edit,
+                       const guint16  channels)
 {
   if (avi_edit && avi_edit->wfx)
     {
@@ -355,8 +364,8 @@ avi_set_channels (AviEdit *avi_edit,
            avi_edit,AVI編集ハンドル
     bits_per_sample,ビット                                                  */
 void
-avi_set_bits_per_sample (AviEdit *avi_edit,
-                         guint16  bits_per_sample)
+avi_edit_set_bits_per_sample (AviEdit       *avi_edit,
+                              const guint16  bits_per_sample)
 {
   if (avi_edit && avi_edit->wfx)
     {
@@ -375,7 +384,7 @@ avi_set_bits_per_sample (AviEdit *avi_edit,
     avi_edit,AVI編集ハンドル
          RET,AVI_TYPE_VIDEO/AVI_TYPE_AUDIO/AVI_TYPE_UNKNOWN                 */
 gint
-avi_type (AviEdit *avi_edit)
+avi_edit_type (AviEdit *avi_edit)
 {
   return avi_edit ? avi_edit->type : AVI_TYPE_UNKNOWN;
 }
@@ -385,7 +394,7 @@ avi_type (AviEdit *avi_edit)
     avi_edit,AVI編集ハンドル
          RET,サンプル数                                                     */
 gint
-avi_length (AviEdit *avi_edit)
+avi_edit_length (AviEdit *avi_edit)
 {
   return avi_edit ? avi_edit->length : 0;
 }
@@ -401,14 +410,14 @@ avi_length (AviEdit *avi_edit)
       sample,サンプル番号
          RET,時間(ミリ秒)                                                   */
 gint
-avi_sample_to_time (AviEdit    *avi_edit,
-                    const gint  sample)
+avi_time_from_sample (AviEdit    *avi_edit,
+                      const gint  sample)
 {
-  switch (avi_type (avi_edit))
+  switch (avi_edit_type (avi_edit))
     {
       case AVI_TYPE_VIDEO:
-        return (glonglong)sample * avi_get_scale (avi_edit) * 1000
-                                                    / avi_get_rate (avi_edit);
+        return (glonglong)sample * avi_edit_get_scale (avi_edit) * 1000
+                                                / avi_edit_get_rate (avi_edit);
       case AVI_TYPE_AUDIO:
         return (glonglong)sample * 1000 / AVI_PCM_SAMPLES_PER_SEC;
     }
@@ -424,11 +433,11 @@ gint
 avi_time_to_sample (AviEdit    *avi_edit,
                     const gint  time)
 {
-  switch (avi_type (avi_edit))
+  switch (avi_edit_type (avi_edit))
     {
       case AVI_TYPE_VIDEO:
-        return (glonglong)time * avi_get_rate (avi_edit)
-                                / ((glonglong)avi_get_scale (avi_edit) * 1000);
+        return (glonglong)time * avi_edit_get_rate (avi_edit)
+                        / ((glonglong)avi_edit_get_scale (avi_edit) * 1000);
       case AVI_TYPE_AUDIO:
         return (glonglong)time * AVI_PCM_SAMPLES_PER_SEC / 1000;
     }
@@ -440,9 +449,9 @@ avi_time_to_sample (AviEdit    *avi_edit,
     avi_edit,AVI編集ハンドル
          RET,時間(ミリ秒)                                                   */
 gint
-avi_length_time (AviEdit *avi_edit)
+avi_time_length (AviEdit *avi_edit)
 {
-  return avi_sample_to_time (avi_edit, avi_length (avi_edit));
+  return avi_time_from_sample (avi_edit, avi_edit_length (avi_edit));
 }
 
 
@@ -452,31 +461,32 @@ avi_length_time (AviEdit *avi_edit)
     avi_edit1,対応先のAVI編集ハンドル
           RET,対応先のサンプル番号                                          */
 gint
-avi_sample_to_sample (AviEdit    *avi_edit0,
+avi_time_sync_sample (AviEdit    *avi_edit0,
                       const gint  sample,
                       AviEdit    *avi_edit1)
 {
-  switch (avi_type (avi_edit0))
+  switch (avi_edit_type (avi_edit0))
     {
       case AVI_TYPE_VIDEO:
-        switch (avi_type (avi_edit1))
+        switch (avi_edit_type (avi_edit1))
           {
             case AVI_TYPE_VIDEO:
               return (glonglong)sample
-                        * avi_get_scale (avi_edit0) * avi_get_rate (avi_edit1)
-                        / ((glonglong)avi_get_rate (avi_edit0)
-                                                * avi_get_scale (avi_edit1));
+                        * avi_edit_get_scale (avi_edit0)
+                        * avi_edit_get_rate (avi_edit1)
+                        / ((glonglong)avi_edit_get_rate (avi_edit0)
+                                            * avi_edit_get_scale (avi_edit1));
             case AVI_TYPE_AUDIO:
-              return (glonglong)sample * avi_get_scale (avi_edit0)
-                        * AVI_PCM_SAMPLES_PER_SEC / avi_get_rate (avi_edit0);
+              return (glonglong)sample * avi_edit_get_scale (avi_edit0)
+                    * AVI_PCM_SAMPLES_PER_SEC / avi_edit_get_rate (avi_edit0);
           }
         break;
       case AVI_TYPE_AUDIO:
-        switch (avi_type (avi_edit1))
+        switch (avi_edit_type (avi_edit1))
           {
             case AVI_TYPE_VIDEO:
-              return (glonglong)sample * avi_get_rate (avi_edit1)
-                                        / ((glonglong)avi_get_scale (avi_edit1)
+              return (glonglong)sample * avi_edit_get_rate (avi_edit1)
+                                / ((glonglong)avi_edit_get_scale (avi_edit1)
                                                     * AVI_PCM_SAMPLES_PER_SEC);
             case AVI_TYPE_AUDIO:
               return sample;
