@@ -648,6 +648,7 @@ avi_play_value_changed (GtkWidget *widget,
 static void
 avi_play_destroy (GtkObject *object)
 {
+  gint i;
   AviPlay *play;
 
   play = AVI_PLAY (object);
@@ -657,9 +658,12 @@ avi_play_destroy (GtkObject *object)
       avi_frame_close (play->avi_frame);
       play->avi_frame = NULL;
     }
-  avi_edit_close (play->avi_edit[0]);
-  avi_edit_close (play->avi_edit[1]);
-  play->avi_edit[0] = play->avi_edit[1] = NULL;
+  for (i = 0; i < 2; i++)
+    if (play->avi_edit[i])
+      {
+        avi_edit_close (play->avi_edit[i]);
+        play->avi_edit[i] = NULL;
+      }
 #ifdef USE_LIBAO
   ao_shutdown ();
 #endif /* USE_LIBAO */
@@ -678,6 +682,18 @@ static void
 avi_play_init (AviPlay *play)
 {
   GtkStyle *style;
+#ifdef USE_LIBAO
+  gint i, index = -1;
+  int count, priority = INT_MIN;
+  ao_info **aoi;
+  struct {
+    int priority;
+    char *name;
+  } driver[] = {{30, "alsa"}, {30, "alsa09"},
+                {20, "oss"},  {20, "irix"},   {20, "sun"},
+                {10, "esd"},  {10, "arts"},
+                { 0, NULL}};
+#endif /* USE_LIBAO */
 #ifdef G_OS_WIN32
   static gboolean register_class = FALSE;
 #endif /* G_OS_WIN32 */
@@ -697,7 +713,47 @@ avi_play_init (AviPlay *play)
   play->avi_pcm = NULL;
 #ifdef USE_LIBAO
   ao_initialize ();
-  play->driver_id = ao_default_driver_id ();
+  play->driver_id = -1;
+  aoi = ao_driver_info_list (&count);
+  for (i = 0; i < count; i++)
+    if (aoi[i]->type == AO_TYPE_LIVE)
+      {
+        gint j;
+
+        for (j = 0; driver[j].name; j++)
+          if (g_strcmp (aoi[i]->short_name, driver[j].name) == 0)
+            {
+              if (driver[j].priority > priority)
+                {
+                  index = i;
+                  priority = driver[j].priority;
+                }
+              break;
+            }
+      }
+  if (index >= 0)
+    play->driver_id = ao_driver_id (aoi[index]->short_name);
+  if (play->driver_id < 0)
+    {
+      priority = INT_MIN;
+      index = -1;
+      for (i = 0; i < count; i++)
+        if (aoi[i]->type == AO_TYPE_LIVE && aoi[i]->priority > priority)
+          {
+            index = i;
+            priority = aoi[i]->priority;
+          }
+      if (index >= 0)
+        play->driver_id = ao_driver_id (aoi[index]->short_name);
+    }
+  if (play->driver_id < 0)
+    for (i = 0; i < count; i++)
+      if (aoi[i]->type == AO_TYPE_LIVE)
+        {
+          play->driver_id = ao_driver_id (aoi[index]->short_name);
+          if (play->driver_id >= 0)
+            break;
+        }
   play->thread = NULL;
 #endif /* USE_LIBAO */
 #ifdef USE_ALSA
@@ -1320,8 +1376,7 @@ avi_play_set_handle (AviPlay  *play,
 
   if (!play)
     return;
-  if (play->playing)
-    avi_play_stop (play);
+  avi_play_stop (play);
   if (play->avi_frame)
     {
       avi_frame_close (play->avi_frame);
@@ -1424,12 +1479,11 @@ avi_play_play (AviPlay *play)
   play->playing = TRUE;
   play->start = play->position;
   if (play->rate > 0 && play->scale > 0)
-    play->timer_id = g_timeout_add_full (G_PRIORITY_LOW,
-            (guint)MAX ((glonglong)play->scale * 1000 / play->rate, 1),
-                                    (GSourceFunc)avi_play_timeout, play, NULL);
+    play->timer_id = g_timeout_add
+                ((guint)MAX ((glonglong)play->scale * 1000 / play->rate, 1),
+                                    (GSourceFunc)avi_play_timeout, play);
   else
-    play->timer_id = g_timeout_add_full (G_PRIORITY_LOW, 100,
-                                    (GSourceFunc)avi_play_timeout, play, NULL);
+    play->timer_id = g_timeout_add (100, (GSourceFunc)avi_play_timeout, play);
 #ifdef USE_LIBAO
   if (play->driver_id >= 0 && play->avi_edit[1]
                         && (play->avi_pcm = avi_pcm_open (play->avi_edit[1])))
