@@ -1025,25 +1025,24 @@ icm_decompress_get_format_size (IcmObject              *icm_object,
 
   if (icm_object && icm_object->hDrvr && bmih)
     {
-      bmih_size = SendDriverMessage (icm_object->hDrvr,
+      gssize size;
+
+      size = SendDriverMessage (icm_object->hDrvr,
                         ICM_DECOMPRESS_GET_FORMAT, GPOINTER_TO_INT (bmih), 0);
-      if (bmih_size > 0)
+      if (size > 0)
         {
           BitmapInfoHeader *bmih_out;
 
-          bmih_out = g_malloc (bmih_size);
+          bmih_out = g_malloc (size);
           if (SendDriverMessage (icm_object->hDrvr, ICM_DECOMPRESS_GET_FORMAT,
                                     GPOINTER_TO_INT (bmih),
                                     GPOINTER_TO_INT (bmih_out)) == ICERR_OK)
             {
+              bmih_size = size;
               if (bmih_size == bmih_get_size (bmih_out)
                         && bm_color_bytes (bmih) == bm_color_bytes (bmih_out))
                 bmih_size += bm_color_bytes (bmih_out);
             }
-          else
-            {
-              bmih_size = 0;
-            }
           g_free (bmih_out);
         }
     }
@@ -1069,7 +1068,7 @@ icm_decompress_get_format (IcmObject              *icm_object,
         && SendDriverMessage (icm_object->hDrvr, ICM_DECOMPRESS_GET_FORMAT,
             GPOINTER_TO_INT (bmih_in), GPOINTER_TO_INT (bmih_out)) == ICERR_OK)
     {
-      gsize bmih_size;
+      gssize bmih_size;
 
       bmih_size = SendDriverMessage (icm_object->hDrvr,
                     ICM_DECOMPRESS_GET_FORMAT, GPOINTER_TO_INT (bmih_in), 0);
