@@ -208,6 +208,21 @@ icm_dialog_configure (IcmObject *icm_object,
                       GtkWidget *widget);
 
 
+/*  ja:ドライバ設定ダイアログのサポートを確認する
+    icm_object,IcmObject
+           RET,TRUE:有効,FALSE:無効                                         */
+gboolean
+icm_is_dialog_preference (IcmObject *icm_object);
+
+
+/*  ja:ドライバ設定ダイアログを表示する
+    icm_object,IcmObject
+        widget,親ウインドウ                                                 */
+void
+icm_dialog_preference (IcmObject *icm_object,
+                       GtkWidget *widget);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ICMパラメータ                                                            *
