@@ -776,9 +776,9 @@ command_reverse (GtkWidget *widget,
     }
   avi_edit = avi_edit_copy (vmaid->avi_edit[0], st, ed - st);
 #ifdef USE_THREAD
-  g_thread_create ((GThreadFunc)reverse_frame, avi_edit, TRUE, NULL);
+  g_thread_create ((GThreadFunc)reverse_frames, avi_edit, TRUE, NULL);
 #else /* not USE_THREAD */
-  reverse_frame (avi_edit);
+  reverse_frames (avi_edit);
 #endif /* not USE_THREAD */
 }
 
