@@ -17,13 +17,9 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "file.h"
-#include "sigfile.h"
-#include "sigmain.h"
 #include "size.h"
 #include "thread.h"
 #include "misc/fileio.h"
-#include "orz/orzhistory.h"
-#include "orz/orzmdi.h"
 
 
 /******************************************************************************
@@ -69,84 +65,6 @@ file_open_avi (AviEdit     *avi_edit[],
 }
 
 
-/*  ja:ウインドウを開く
-    vmaid,ウインドウ情報
-     file,ファイル名
-      RET,TRUE:正常終了,FALSE:エラー                                        */
-gboolean
-file_open_window (VmaidWindow *vmaid,
-                  const gchar *file)
-{
-  gchar *filename;
-  gint page_num;
-  GtkWidget *xbox, *vbox;
-  const static gchar *rot47 = "\0"
-        "%9:D AC@8C2> 4@>6D H:E9 }~ (p##p}%*[ E@ E96 6IE6?E A6C>:EE65 3J =2H]";
-
-  if (file)
-    {
-      filename = fileio_get_full_path (file);
-    }
-  else
-    {
-      static gint fcount = 0; /* ja:新規ファイルの数 */
-
-      /* ja:新規 */
-      filename = g_strdup_printf ("new%04d.avi", fcount++ % 1000);
-    }
-  /* ja:表示エリア */
-  vmaid->drawing = gtk_drawing_area_new ();
-  g_signal_connect (G_OBJECT (vmaid->drawing), "focus-in-event",
-                                G_CALLBACK (signal_focus_in), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "focus-out-event",
-                                G_CALLBACK (signal_focus_out), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "realize",
-                                G_CALLBACK (signal_realize), NULL);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "configure-event",
-                                G_CALLBACK (signal_config), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "expose-event",
-                                G_CALLBACK (signal_expose), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "button-press-event",
-                                G_CALLBACK (signal_button_press_draw), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "motion-notify-event",
-                                G_CALLBACK (signal_motion_notify), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "button-release-event",
-                                G_CALLBACK (signal_button_release), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "scroll-event",
-                                G_CALLBACK (signal_scroll), vmaid);
-  g_signal_connect_after (G_OBJECT (vmaid->drawing), "key-press-event",
-                                G_CALLBACK (signal_key_press), vmaid);
-  g_signal_connect (GTK_OBJECT (vmaid->drawing), "destroy",
-                                G_CALLBACK (signal_destroy_draw), vmaid);
-  gtk_widget_add_events (vmaid->drawing, GDK_POINTER_MOTION_MASK
-                            | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
-                            | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
-                            | GDK_FOCUS_CHANGE_MASK | GDK_SCROLL_MASK);
-  gtk_widget_set_size_request (vmaid->drawing,
-                    vmaid->width + (vmaid->selfrm ? vmaid->width * 2 + 4 : 2),
-                        system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
-                            + (vmaid->avi_edit[1] ? 1 : 0)) * vmaid->height);
-  GTK_WIDGET_SET_FLAGS (vmaid->drawing, GTK_CAN_FOCUS);
-  /* ja:スクロールバー */
-  vmaid->hscroll = gtk_hscrollbar_new
-                    (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 0, 1, 1, 1)));
-  /* ja:ボックス */
-  xbox = gtk_hbox_new (FALSE, 0);
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), vmaid->drawing, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), vmaid->hscroll, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (xbox), vbox, *rot47, *rot47, 0);
-  /* ja:表示 */
-  page_num = orz_mdi_append_page (ORZ_MDI (mdi),
-                                        xbox, filename, file != NULL, vmaid);
-  gtk_widget_show_all (xbox);
-  gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page_num);
-  gtk_widget_grab_focus (vmaid->drawing);
-  g_free (filename);
-  return TRUE;
-}
-
-
 /*  ja:ファイルを開く(独立スレッド)
     file_open,Open情報
      RET,ウインドウ情報                                                     */
@@ -303,6 +221,7 @@ file_open_edit (FileOpen *file_open)
         if (vmaid->avi_edit[i])
           avi_edit_close (vmaid->avi_edit[i]);
       g_free (vmaid);
+      thread_delete (id);
       return NULL;
     }
 
@@ -323,16 +242,10 @@ file_open_edit (FileOpen *file_open)
         vmaid->cursor.stream = 1;
     }
 
-#ifdef USE_THREAD
-  gdk_threads_enter ();
-#endif /* USE_THREAD */
-  file_open_window (vmaid, file_open ? file_open->file : NULL);
+  thread_window (vmaid, file_open ? file_open->file : NULL);
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
   if (file_open && g_file_test (file_open->file, G_FILE_TEST_EXISTS))
-    orz_history_add_file (ORZ_HISTORY (history), file_open->file);
-#ifdef USE_THREAD
-  gdk_threads_leave ();
-#endif /* USE_THREAD */
+    thread_history (file_open->file);
 
   if (file_open)
     {
