@@ -635,7 +635,7 @@ get_max_frame (VmaidWindow *vmaid,
     avi_edit,AVI編集構造体
          RET,TRUE:正常終了,FALSE:エラー                                     */
 gboolean
-reverse_frame (AviEdit *avi_edit)
+reverse_frames (AviEdit *avi_edit)
 {
   gint i;
   VmaidWindow *vmaid;
@@ -701,13 +701,7 @@ reverse_frame (AviEdit *avi_edit)
                                     avi_edit_get_height (vmaid->avi_edit[0]));
       vmaid->rate = avi_edit_get_rate (vmaid->avi_edit[0]);
       vmaid->scale = avi_edit_get_scale (vmaid->avi_edit[0]);
-#ifdef USE_THREAD
-      gdk_threads_enter ();
-#endif /* USE_THREAD */
-      file_open_window (vmaid, NULL);
-#ifdef USE_THREAD
-      gdk_threads_leave ();
-#endif /* USE_THREAD */
+      thread_window (vmaid, NULL);
     }
   else
     {
