@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,8 +30,10 @@ extern "C" {
 
 typedef struct _JumpConfig
 {
-  gint frame, max;
+  gboolean video, audio;
+  gint max;
   guint32 rate, scale;
+  VmaidCursor cursor, select;
 } JumpConfig;
 
 
