@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include "file.h"
 #include "merge.h"
 #include "size.h"
+#include "thread.h"
 #include "misc/fileio.h"
 #include "orz/orzmdi.h"
 
@@ -483,7 +484,7 @@ merge_dialog (void)
           if (vmaid->avi_edit[1])
             vmaid->cursor.stream = 1;
         }
-      file_open_window (vmaid, NULL);
+      thread_window (vmaid, NULL);
     }
   loop:
   gtk_widget_destroy (mrgdlg.dialog);
