@@ -441,10 +441,17 @@ signal_delete (GtkWidget *widget,
         return TRUE;
       gtk_notebook_remove_page (GTK_NOTEBOOK (mdi), page);
     }
-#ifdef USE_THREAD
-  g_thread_create ((GThreadFunc)close_program, NULL, TRUE, NULL);
-#else /* not USE_THREAD */
-  close_program ();
-#endif /* not USE_THREAD */
+  thread_exit ();
   return TRUE;
 }
+
+
+#ifdef USE_THREAD
+void
+signal_destroy (GtkWidget *widget,
+                gpointer   user_data)
+{
+  g_source_remove (GPOINTER_TO_UINT (user_data));
+  gtk_main_quit ();
+}
+#endif /* USE_THREAD */
