@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -125,6 +125,13 @@ signal_delete (GtkWidget *widget,
                gpointer   user_data);
 
 
+#ifdef USE_THREAD
+void
+signal_destroy (GtkWidget *widget,
+                gpointer   user_data);
+#endif /* USE_THREAD */
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
