@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,24 +63,41 @@ extern "C" {
 #endif /* not USE_THREAD */
 
 
-typedef struct _ThreadList
-{
-  gboolean userbreak;   /* ja:TRUE:継続,FALSE:中断要求 */
-  gint mode;            /* ja:0:終了,1:開く,2:保存,3:フレーム数,4:反転 */
-  gint percent;         /* ja:進行状況(0...100) */
+/******************************************************************************
+*                                                                             *
+* ja:スレッド描画関数群                                                       *
+*                                                                             *
+******************************************************************************/
 #ifdef USE_THREAD
-  GThread *id;
-#else /* not USE_THREAD */
-  gint id;
-#endif /* not USE_THREAD */
-} ThreadList;
+/*  ja:スレッドのアイドル処理
+    data,データ
+     RET,TRUE:継続,FALSE:終了                                               */
+gboolean
+thread_idle (gpointer data);
+#endif /* USE_THREAD */
 
 
 /******************************************************************************
 *                                                                             *
-* ja:スレッド関数群                                                           *
+* ja:スレッド制御関数群                                                       *
 *                                                                             *
 ******************************************************************************/
+/*  ja:ウインドウを開く
+    vmaid,ウインドウ情報
+     file,ファイル名
+      RET,TRUE:正常終了,FALSE:エラー                                        */
+gboolean
+thread_window (VmaidWindow *vmaid,
+               const gchar *file);
+
+
+/*  ja:履歴に追加する
+    file,ファイル名
+     RET,TRUE:正常終了,FALSE:エラー                                         */
+gboolean
+thread_history (const gchar *file);
+
+
 /*  ja:リストに加える
       id,スレッドID
     mode,モード(0:終了,1:開く,2:保存,3:フレーム数,4:反転)
@@ -107,7 +124,7 @@ gboolean
 thread_delete (GThread *id);
 #else /* not USE_THREAD */
 gboolean
-thread_delete(gint id);
+thread_delete (gint id);
 #endif /* not USE_THREAD */
 
 
@@ -133,9 +150,10 @@ gboolean
 thread_break (const gboolean all);
 
 
-/*  ja:プログラムの終了(独立スレッド)                                       */
-void *
-close_program (void);
+/*  ja:プログラムを終了させる
+    RET,TRUE:正常終了,FALSE:エラー                                          */
+gboolean
+thread_exit (void);
 
 
 #ifdef __cplusplus
