@@ -366,8 +366,10 @@ VMAID_COPYRIGHT_NOTICE"\n"
   g_list_free (glist);
   g_signal_connect (G_OBJECT (window), "delete-event",
                                             G_CALLBACK (signal_delete), NULL);
+#ifndef USE_THREAD
   g_signal_connect (G_OBJECT (window), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
+#endif /* not USE_THREAD */
   gtk_widget_realize (window);
   /* en:Drag and Drop */
   gtk_drag_dest_set (window, GTK_DEST_DEFAULT_ALL,
@@ -612,6 +614,9 @@ VMAID_COPYRIGHT_NOTICE"\n"
 
 #ifdef USE_THREAD
   gdk_threads_enter ();
+  g_signal_connect (G_OBJECT (window), "destroy",
+                    G_CALLBACK (signal_destroy),
+                    GUINT_TO_POINTER (g_timeout_add (500, thread_idle, NULL)));
 #endif /* USE_THREAD */
   gtk_main ();
 #ifdef USE_THREAD
