@@ -20,7 +20,7 @@
 #define __VMAID_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 #include "avicore/avicore.h"
 #include "misc/misc.h"
 #ifdef G_OS_WIN32
@@ -87,9 +87,8 @@ extern GtkWidget *mdi;                  /* en:MDI */
 extern GtkWidget *tview;                /* ja:リストボックス */
 extern GtkWidget *status;               /* ja:ステータスウインドウ */
 extern GtkPositionType n_pos;           /* ja:ノートブックの位置 */
-extern GdkFont *system_font;            /* ja:フォント */
+extern PangoLayout *system_font_layout;
 extern gint system_font_height;         /* ja:フォントの高さ */
-extern gint system_font_ascent;         /* ja:フォントのアクセントの高さ */
 extern GdkColor system_color[4];
 extern MiscCreateMenuEntry menu_entries[];
 extern MiscCreateMenuEntry popup_entries[];
