@@ -40,11 +40,12 @@ typedef LPVOID LPCRITICAL_SECTION;
 typedef INT CALLBACK (*FARPROC)();
 
 /* ja:ウエイト */
-#define WAIT_FAILED    0xffffffff
-#define WAIT_OBJECT_0  0x00000000
-#define WAIT_ABANDONED 0x00000080
-#define WAIT_TIMEOUT   0x00000102
-#define INFINITE       0xffffffff
+#define WAIT_FAILED      0xffffffff
+#define WAIT_OBJECT_0    0x00000000
+#define WAIT_ABANDONED   0x00000080
+#define WAIT_ABANDONED_0 WAIT_ABANDONED
+#define WAIT_TIMEOUT     0x00000102
+#define INFINITE         0xffffffff
 
 /* ja:プロセス */
 #include "pshpack1.h"
@@ -55,6 +56,26 @@ typedef struct _PROCESS_INFORMATION
   DWORD dwProcessId;
   DWORD dwThreadId;
 } PROCESS_INFORMATION, *PPROCESS_INFORMATION, *LPPROCESS_INFORMATION;
+#include "poppack.h"
+#define FOREGROUND_BLUE      0x0001
+#define FOREGROUND_GREEN     0x0002
+#define FOREGROUND_RED       0x0004
+#define FOREGROUND_INTENSITY 0x0008
+#define BACKGROUND_BLUE      0x0010
+#define BACKGROUND_GREEN     0x0020
+#define BACKGROUND_RED       0x0040
+#define BACKGROUND_INTENSITY 0x0080
+#define STARTF_USESHOWWINDOW    0x00000001
+#define STARTF_USESIZE          0x00000002
+#define STARTF_USEPOSITION      0x00000004
+#define STARTF_USECOUNTCHARS    0x00000008
+#define STARTF_USEFILLATTRIBUTE 0x00000010
+#define STARTF_RUNFULLSCREEN    0x00000020
+#define STARTF_FORCEONFEEDBACK  0x00000040
+#define STARTF_FORCEOFFFEEDBACK 0x00000080
+#define STARTF_USESTDHANDLES    0x00000100
+#define STARTF_USEHOTKEY        0x00000200
+#include "pshpack1.h"
 typedef struct _STARTUPINFOA
 {
   DWORD cb;
@@ -106,6 +127,20 @@ typedef struct _STARTUPINFOW
 # define LPSTARTUPINFO LPSTARTUPINFOA
 #endif /* not UNICODE */
 
+/* ja:スレッド */
+#define THREAD_BASE_PRIORITY_LOWRT 15
+#define THREAD_BASE_PRIORITY_MAX   2
+#define THREAD_BASE_PRIORITY_MIN   (-2)
+#define THREAD_BASE_PRIORITY_IDLE  (-15)
+#define THREAD_PRIORITY_LOWEST        THREAD_BASE_PRIORITY_MIN
+#define THREAD_PRIORITY_BELOW_NORMAL  (THREAD_PRIORITY_LOWEST+1)
+#define THREAD_PRIORITY_NORMAL        0
+#define THREAD_PRIORITY_HIGHEST       THREAD_BASE_PRIORITY_MAX
+#define THREAD_PRIORITY_ABOVE_NORMAL  (THREAD_PRIORITY_HIGHEST-1)
+#define THREAD_PRIORITY_ERROR_RETURN  (0x7fffffff)
+#define THREAD_PRIORITY_TIME_CRITICAL THREAD_BASE_PRIORITY_LOWRT
+#define THREAD_PRIORITY_IDLE          THREAD_BASE_PRIORITY_IDLE
+
 /* ja:メモリ */
 #define GMEM_FIXED          0x0000
 #define GMEM_MOVEABLE       0x0002
@@ -139,6 +174,14 @@ typedef struct _STARTUPINFOW
 #define LMEM_INVALID_HANDLE GMEM_INVALID_HANDLE
 #define LHND                GHND
 #define LPTR                GPTR
+#define MEM_COMMIT      0x00001000
+#define MEM_RESERVE     0x00002000
+#define MEM_DECOMMIT    0x00004000
+#define MEM_RELEASE     0x00008000
+#define MEM_RESET       0x00080000
+#define MEM_TOP_DOWN    0x00100000
+#define MEM_WRITE_WATCH 0x00200000
+#define MEM_PHYSICAL    0x00400000
 typedef LPVOID HGLOBAL, HLOCAL;
 #include "pshpack1.h"
 typedef struct _MEMORY_BASIC_INFORMATION
@@ -265,6 +308,17 @@ typedef struct _WIN32_FIND_DATAW
 # define LPWIN32_FIND_DATA LPWIN32_FIND_DATAA
 #endif /* not UNICODE */
 
+/* ja:文字列比較 */
+#define CSTR_LESS_THAN    1
+#define CSTR_EQUAL        2
+#define CSTR_GREATER_THAN 3
+#define NORM_IGNORECASE     0x00001
+#define NORM_IGNORENONSPACE 0x00002
+#define NORM_IGNORESYMBOLS  0x00004
+#define NORM_STRINGSORT     0x01000
+#define NORM_IGNOREKANATYPE 0x10000
+#define NORM_IGNOREWIDTH    0x20000
+
 /* ja:言語/ロケール/コードページ */
 #define MAX_DEFAULTCHAR 2
 #define MAX_LEADBYTES   12
@@ -605,11 +659,15 @@ typedef struct
 # define POSVERSIONINFO POSVERSIONINFOA
 # define LPOSVERSIONINFO LPOSVERSIONINFOA
 #endif /* not UNICODE */
+/* dwProcessorType */
+#define PROCESSOR_INTEL_386     386
+#define PROCESSOR_INTEL_486     486
+#define PROCESSOR_INTEL_PENTIUM 586
 #include "pshpack1.h"
 typedef struct _SYSTEM_INFO
 {
   union {
-  DWORD dwOemId;
+    DWORD dwOemId;
     struct {
       WORD wProcessorArchitecture;
       WORD wReserved;
@@ -636,6 +694,22 @@ typedef struct _SYSTEMTIME
   WORD wSecond;
   WORD wMilliseconds;
 } SYSTEMTIME, *PSYSTEMTIME, *LPSYSTEMTIME;
+typedef CONST SYSTEMTIME *PCSYSTEMTIME, *LPCSYSTEMTIME;
+#define TIME_ZONE_ID_INVALID  0xffffffff
+#define TIME_ZONE_ID_UNKNOWN  0
+#define TIME_ZONE_ID_STANDARD 1
+#define TIME_ZONE_ID_DAYLIGHT 2
+typedef struct _TIME_ZONE_INFORMATION
+{
+  LONG Bias;
+  WCHAR StandardName[32];
+  SYSTEMTIME StandardDate;
+  LONG StandardBias;
+  WCHAR DaylightName[32];
+  SYSTEMTIME DaylightDate;
+  LONG DaylightBias;
+} TIME_ZONE_INFORMATION, *PTIME_ZONE_INFORMATION, *LPTIME_ZONE_INFORMATION;
+typedef CONST TIME_ZONE_INFORMATION *PCTIME_ZONE_INFORMATION, *LPCTIME_ZONE_INFORMATION;
 #include "poppack.h"
 
 /* ja:コンソール */
@@ -645,10 +719,79 @@ typedef struct tagCOORD
   SHORT X;
   SHORT Y;
 } COORD, *PCOORD, *LPCOORD;
+#include "poppack.h"
 
 /* ja:非公開 */
 #define EXCEPTION_MAXIMUM_PARAMETERS 15
-typedef struct _EXCEPTION_RECORD
+#define MAXIMUM_SUPPORTED_EXTENSION 512
+#define SIZE_OF_80387_REGISTERS 80
+typedef struct _FLOATING_SAVE_AREA FLOATING_SAVE_AREA, *PFLOATING_SAVE_AREA, *LPFLOATING_SAVE_AREA;
+typedef struct _CONTEXT86 CONTEXT86, *PCONTEXT86, *LPCONTEXT86, CONTEXT, *PCONTEXT, *LPCONTEXT;
+typedef struct _EXCEPTION_FRAME EXCEPTION_FRAME, *PEXCEPTION_FRAME, *LPEXCEPTION_FRAME;
+typedef struct _EXCEPTION_POINTERS EXCEPTION_POINTERS, *PEXCEPTION_POINTERS, *LPEXCEPTION_POINTERS;
+typedef struct _EXCEPTION_RECORD EXCEPTION_RECORD, *PEXCEPTION_RECORD, *LPEXCEPTION_RECORD;
+typedef struct _EXCEPTION_REGISTRATION_RECORD EXCEPTION_REGISTRATION_RECORD, *PEXCEPTION_REGISTRATION_RECORD, *LPEXCEPTION_REGISTRATION_RECORD;
+typedef struct _SCOPETABLE SCOPETABLE, *PSCOPETABLE, *LPSCOPETABLE;
+typedef DWORD (*PEXCEPTION_HANDLER)(PEXCEPTION_RECORD, PEXCEPTION_REGISTRATION_RECORD, PCONTEXT, EXCEPTION_REGISTRATION_RECORD **);
+typedef DWORD (*LPEXCEPTION_HANDLER)(LPEXCEPTION_RECORD, LPEXCEPTION_REGISTRATION_RECORD, LPCONTEXT, EXCEPTION_REGISTRATION_RECORD **);
+typedef LONG (CALLBACK *PTOP_LEVEL_EXCEPTION_FILTER)(PEXCEPTION_POINTERS);
+typedef LONG (CALLBACK *LPTOP_LEVEL_EXCEPTION_FILTER)(LPEXCEPTION_POINTERS);
+#include "pshpack1.h"
+struct _FLOATING_SAVE_AREA
+{
+  DWORD ControlWord;
+  DWORD StatusWord;
+  DWORD TagWord;
+  DWORD ErrorOffset;
+  DWORD ErrorSelector;
+  DWORD DataOffset;
+  DWORD DataSelector;
+  BYTE RegisterArea[SIZE_OF_80387_REGISTERS];
+  DWORD Cr0NpxState;
+};
+struct _CONTEXT86
+{
+  DWORD ContextFlags;
+  DWORD Dr0;
+  DWORD Dr1;
+  DWORD Dr2;
+  DWORD Dr3;
+  DWORD Dr6;
+  DWORD Dr7;
+  FLOATING_SAVE_AREA FloatSave;
+  DWORD SegGs;
+  DWORD SegFs;
+  DWORD SegEs;
+  DWORD SegDs;
+  DWORD Edi;
+  DWORD Esi;
+  DWORD Ebx;
+  DWORD Edx;
+  DWORD Ecx;
+  DWORD Eax;
+  DWORD Ebp;
+  DWORD Eip;
+  DWORD SegCs;
+  DWORD EFlags;
+  DWORD Esp;
+  DWORD SegSs;
+  BYTE ExtendedRegisters[MAXIMUM_SUPPORTED_EXTENSION];
+};
+struct _EXCEPTION_FRAME
+{
+  EXCEPTION_REGISTRATION_RECORD *prev;
+  void (*handler)(PEXCEPTION_RECORD, PEXCEPTION_REGISTRATION_RECORD, PCONTEXT, PEXCEPTION_RECORD);
+  PSCOPETABLE scopetable;
+  int trylevel;
+  int _ebp;
+  PEXCEPTION_POINTERS xpointers;
+};
+struct _EXCEPTION_POINTERS
+{
+  PEXCEPTION_RECORD ExceptionRecord;
+  PCONTEXT ContextRecord;
+};
+struct _EXCEPTION_RECORD
 {
   DWORD ExceptionCode;
   DWORD ExceptionFlags;
@@ -656,7 +799,18 @@ typedef struct _EXCEPTION_RECORD
   PVOID ExceptionAddress;
   DWORD NumberParameters;
   ULONG_PTR ExceptionInformation[EXCEPTION_MAXIMUM_PARAMETERS];
-} EXCEPTION_RECORD, *PEXCEPTION_RECORD, *LPEXCEPTION_RECORD;
+};
+struct _EXCEPTION_REGISTRATION_RECORD
+{
+  struct _EXCEPTION_REGISTRATION_RECORD *Prev;
+  PEXCEPTION_HANDLER Handler;
+};
+struct _SCOPETABLE
+{
+  int previousTryLevel;
+  int (*lpfnFilter)(PEXCEPTION_POINTERS);
+  int (*lpfnHandler)(void);
+};
 #include "poppack.h"
 
 
@@ -667,7 +821,9 @@ ATOM WINAPI AddAtomA (LPCSTR lpString);
 ATOM WINAPI AddAtomW (LPCWSTR lpString);
 BOOL WINAPI AllocConsole (VOID);
 BOOL WINAPI CloseHandle (HANDLE hObject);
-LONG WINAPI CompareFileTime (CONST LPFILETIME lpFileTime1, CONST LPFILETIME lpFileTime2);
+LONG WINAPI CompareFileTime (LPCFILETIME lpFileTime1, LPCFILETIME lpFileTime2);
+INT WINAPI CompareStringA (LCID Locale, DWORD dwCmpFlags, LPCSTR lpString1, INT cchCount1, LPCSTR lpString2, INT cchCount2);
+INT WINAPI CompareStringW (LCID Locale, DWORD dwCmpFlags, LPCWSTR lpString1, INT cchCount1, LPCWSTR lpString2, INT cchCount2);
 BOOL WINAPI CopyFileA (LPCSTR lpExistingFileName, LPCSTR lpNewFileName, BOOL bFailIfExists);
 BOOL WINAPI CopyFileW (LPCWSTR lpExistingFileName, LPCWSTR lpNewFileName, BOOL bFailIfExists);
 BOOL WINAPI CreateDirectoryA (LPCSTR lpPathName, LPSECURITY_ATTRIBUTES lpSecurityAttributes);
@@ -695,8 +851,8 @@ BOOL WINAPI EnumCalendarInfoA (CALINFO_ENUMPROCA lpCalInfoEnumProc, LCID Locale,
 BOOL WINAPI EnumCalendarInfoW (CALINFO_ENUMPROCW lpCalInfoEnumProc, LCID Locale, CALID Calendar, CALTYPE CalType);
 VOID WINAPI ExitProcess (UINT uExitCode);
 VOID WINAPI ExitThread (UINT uExitCode);
-BOOL WINAPI FileTimeToLocalFileTime (CONST LPFILETIME lpFileTime, LPFILETIME lpLocalFileTime);
-BOOL WINAPI FileTimeToSystemTime (CONST LPFILETIME lpFileTime, LPSYSTEMTIME lpSystemTime);
+BOOL WINAPI FileTimeToLocalFileTime (LPCFILETIME lpFileTime, LPFILETIME lpLocalFileTime);
+BOOL WINAPI FileTimeToSystemTime (LPCFILETIME lpFileTime, LPSYSTEMTIME lpSystemTime);
 ATOM WINAPI FindAtomA (LPCSTR lpString);
 ATOM WINAPI FindAtomW (LPCWSTR lpString);
 BOOL WINAPI FindClose (HANDLE hFind);
@@ -739,6 +895,8 @@ DWORD WINAPI GetFileAttributesW (LPCWSTR lpFileName);
 DWORD WINAPI GetFileSize (HANDLE hFile, LPDWORD lpFileSizeHigh);
 BOOL WINAPI GetFileTime (HANDLE hFile, LPFILETIME lpCreationTime, LPFILETIME lpLastAccessTime, LPFILETIME lpLastWriteTime);
 DWORD WINAPI GetFileType (HANDLE hFile);
+DWORD WINAPI GetFullPathNameA (LPCSTR lpFileName, DWORD nBufferLength, LPSTR lpBuffer, LPSTR *lpFilePart);
+DWORD WINAPI GetFullPathNameW (LPCWSTR lpFileName, DWORD nBufferLength, LPWSTR lpBuffer, LPWSTR *lpFilePart);
 DWORD WINAPI GetLastError (VOID);
 VOID WINAPI GetLocalTime (LPSYSTEMTIME lpSystemTime);
 INT WINAPI GetLocaleInfoA (LCID Locale, LCTYPE LCType, LPSTR lpLCData, INT cchData);
@@ -760,6 +918,7 @@ DWORD WINAPI GetPrivateProfileStringW (LPCWSTR lpAppName, LPCWSTR lpKeyName, LPC
 BOOL WINAPI GetPrivateProfileStructA (LPCSTR lpszSection, LPCSTR lpszKey, LPVOID lpStruct, UINT uSizeStruct, LPCSTR szFile);
 BOOL WINAPI GetPrivateProfileStructW (LPCWSTR lpszSection, LPCWSTR lpszKey, LPVOID lpStruct, UINT uSizeStruct, LPCWSTR szFile);
 FARPROC WINAPI GetProcAddress (HMODULE hModule, LPCSTR lpProcName);
+BOOL WINAPI GetProcessAffinityMask (HANDLE hProcess, LPDWORD lpProcessAffinityMask, LPDWORD lpSystemAffinityMask);
 HANDLE WINAPI GetProcessHeap (VOID);
 DWORD WINAPI GetProcessHeaps (DWORD NumberOfHeaps, HANDLE *ProcessHeaps);
 UINT WINAPI GetProfileIntA (LPCSTR lpAppName, LPCSTR lpKeyName, INT nDefault);
@@ -770,6 +929,8 @@ DWORD WINAPI GetProfileStringA (LPCSTR lpAppName, LPCSTR lpKeyName, LPCSTR lpDef
 DWORD WINAPI GetProfileStringW (LPCWSTR lpAppName, LPCWSTR lpKeyName, LPCWSTR lpDefault, LPWSTR lpReturnedString, DWORD nSize);
 DWORD WINAPI GetShortPathNameA (LPCSTR lpszLongPath, LPSTR lpszShortPath, DWORD cchBuffer);
 DWORD WINAPI GetShortPathNameW (LPCWSTR lpszLongPath, LPWSTR lpszShortPath, DWORD cchBuffer);
+VOID WINAPI GetStartupInfoA (LPSTARTUPINFOA lpsi);
+VOID WINAPI GetStartupInfoW (LPSTARTUPINFOW lpsi);
 HANDLE WINAPI GetStdHandle (DWORD nStdHandle);
 BOOL WINAPI GetStringTypeA (LCID Locale, DWORD dwInfoType, LPCSTR lpSrcStr, INT cchSrc, LPWORD lpCharType);
 BOOL WINAPI GetStringTypeW (DWORD dwInfoType, LPCWSTR lpSrcStr, INT cchSrc, LPWORD lpCharType);
@@ -778,10 +939,17 @@ LANGID WINAPI GetSystemDefaultLangID (VOID);
 LANGID WINAPI GetSystemDefaultUILanguage (VOID);
 UINT WINAPI GetSystemDirectoryA (LPSTR lpBuffer, UINT uSize);
 UINT WINAPI GetSystemDirectoryW (LPWSTR lpBuffer, UINT uSize);
+VOID WINAPI GetSystemInfo (LPSYSTEM_INFO lpSystemInfo);
+VOID WINAPI GetSystemTime (LPSYSTEMTIME lpSystemTime);
+VOID WINAPI GetSystemTimeAsFileTime (LPFILETIME lpSystemTimeAsFileTime);
+UINT WINAPI GetTempFileNameA (LPCSTR lpPathName, LPCSTR lpPrefixString, UINT uUnique, LPSTR lpTempFileName);
+UINT WINAPI GetTempFileNameW (LPCWSTR lpPathName, LPCWSTR lpPrefixString, UINT uUnique, LPWSTR lpTempFileName);
 DWORD WINAPI GetTempPathA (DWORD nBufferLength, LPSTR lpBuffer);
 DWORD WINAPI GetTempPathW (DWORD nBufferLength, LPWSTR lpBuffer);
 LCID WINAPI GetThreadLocale (VOID);
+INT WINAPI GetThreadPriority (HANDLE hThread);
 DWORD WINAPI GetTickCount (VOID);
+DWORD WINAPI GetTimeZoneInformation (LPTIME_ZONE_INFORMATION lpTimeZoneInformation);
 DWORD WINAPI GetUserDefaultLCID (VOID);
 LANGID WINAPI GetUserDefaultLangID (VOID);
 LANGID WINAPI GetUserDefaultUILanguage (VOID);
@@ -830,7 +998,7 @@ HINSTANCE WINAPI LoadLibraryExW (LPCWSTR lpLibFileName, HANDLE hFile, DWORD dwFl
 HINSTANCE WINAPI LoadLibraryW (LPCWSTR lpFileName);
 HGLOBAL WINAPI LoadResource (HMODULE hModule, HRSRC hResInfo);
 HLOCAL WINAPI LocalAlloc (UINT uFlags, UINT uBytes);
-BOOL WINAPI LocalFileTimeToFileTime (CONST LPFILETIME lpLocalFileTime, LPFILETIME lpFileTime);
+BOOL WINAPI LocalFileTimeToFileTime (LPCFILETIME lpLocalFileTime, LPFILETIME lpFileTime);
 UINT WINAPI LocalFlags (HLOCAL hMem);
 HLOCAL WINAPI LocalFree (HLOCAL hMem);
 HLOCAL WINAPI LocalHandle (LPCVOID pMem);
@@ -860,26 +1028,36 @@ VOID WINAPI OutputDebugStringW (LPCWSTR lpOutputString);
 BOOL WINAPI PulseEvent (HANDLE hEvent);
 BOOL WINAPI QueryPerformanceCounter (LARGE_INTEGER *lpPerformanceCount);
 BOOL WINAPI QueryPerformanceFrequency (LARGE_INTEGER *lpFrequency);
+VOID WINAPI RaiseException (DWORD dwExceptionCode, DWORD dwExceptionFlags, DWORD nNumberOfArguments, CONST ULONG_PTR *lpArguments);
 BOOL WINAPI ReadFile (HANDLE hFile, LPVOID lpBuffer, DWORD nNumberOfBytesToRead, LPDWORD lpNumberOfBytesRead, LPOVERLAPPED lpOverlapped);
 BOOL WINAPI ReleaseMutex (HANDLE hMutex);
 BOOL WINAPI ReleaseSemaphore (HANDLE hSemaphore, LONG lReleaseCount, LPLONG lpPreviousCount);
 BOOL WINAPI RemoveDirectoryA (LPCSTR lpPathName);
 BOOL WINAPI RemoveDirectoryW (LPCWSTR lpPathName);
 BOOL WINAPI ResetEvent (HANDLE hEvent);
+DWORD WINAPI ResumeThread (HANDLE hThread);
 VOID WINAPI RtlUnwind (PVOID TargetFrame, PVOID TargetIp, PEXCEPTION_RECORD ExceptionRecord, PVOID ReturnValue);
 BOOL WINAPI SetConsoleScreenBufferSize (HANDLE hConsoleOutput, COORD dwSize);
 BOOL WINAPI SetCurrentDirectoryA (LPCSTR lpPathName);
 BOOL WINAPI SetCurrentDirectoryW (LPCWSTR lpPathName);
 BOOL WINAPI SetEndOfFile (HANDLE hFile);
+BOOL WINAPI SetEnvironmentVariableA (LPCSTR lpName, LPCSTR lpValue);
+BOOL WINAPI SetEnvironmentVariableW (LPCWSTR lpName, LPCWSTR lpValue);
 BOOL WINAPI SetEvent (HANDLE hEvent);
 DWORD WINAPI SetFilePointer (HANDLE hFile, LONG lDistanceToMove, PLONG lpDistanceToMoveHigh, DWORD dwMoveMethod);
-BOOL WINAPI SetFileTime (HANDLE hFile, CONST LPFILETIME lpCreationTime, CONST LPFILETIME lpLastAccessTime, CONST LPFILETIME lpLastWriteTime);
+BOOL WINAPI SetFileTime (HANDLE hFile, LPCFILETIME lpCreationTime, LPCFILETIME lpLastAccessTime, LPCFILETIME lpLastWriteTime);
 UINT WINAPI SetHandleCount (UINT uNumber);
 VOID WINAPI SetLastError (DWORD dwErrCode);
+BOOL WINAPI SetProcessAffinityMask (HANDLE hProcess, DWORD dwProcessAffinityMask);
 BOOL WINAPI SetStdHandle (DWORD nStdHandle, HANDLE hHandle);
+DWORD WINAPI SetThreadAffinityMask (HANDLE hThread, DWORD dwThreadAffinityMask);
+BOOL WINAPI SetThreadPriority (HANDLE hThread, INT nPriority);
+BOOL WINAPI SetTimeZoneInformation (LPCTIME_ZONE_INFORMATION lpTimeZoneInformation);
+LPTOP_LEVEL_EXCEPTION_FILTER WINAPI SetUnhandledExceptionFilter (LPTOP_LEVEL_EXCEPTION_FILTER lpTopLevelExceptionFilter);
 DWORD WINAPI SizeofResource (HMODULE hModule, HRSRC hResInfo);
 VOID WINAPI Sleep (DWORD dwMilliseconds);
-BOOL WINAPI SystemTimeToFileTime (CONST LPSYSTEMTIME lpSystemTime, LPFILETIME lpFileTime);
+DWORD WINAPI SuspendThread (HANDLE hThread);
+BOOL WINAPI SystemTimeToFileTime (LPCSYSTEMTIME lpSystemTime, LPFILETIME lpFileTime);
 BOOL WINAPI TerminateProcess (HANDLE hProcess, UINT uExitCode);
 DWORD WINAPI TlsAlloc (VOID);
 BOOL WINAPI TlsFree (DWORD dwTlsIndex);
@@ -895,10 +1073,11 @@ BOOL WINAPI VirtualLock (LPVOID lpAddress, DWORD dwSize);
 BOOL WINAPI VirtualProtect (LPVOID lpAddress, DWORD dwSize, DWORD flNewProtect, PDWORD lpflOldProtect);
 DWORD WINAPI VirtualQuery (LPCVOID lpAddress, PMEMORY_BASIC_INFORMATION lpBuffer, DWORD dwLength);
 BOOL WINAPI VirtualUnlock (LPVOID lpAddress, DWORD dwSize);
+DWORD WINAPI WaitForMultipleObjects (DWORD nCount, CONST HANDLE *lpHandles, BOOL fWaitAll, DWORD dwMilliseconds);
 DWORD WINAPI WaitForSingleObject (HANDLE hHandle, DWORD dwMilliseconds);
 INT WINAPI WideCharToMultiByte (UINT CodePage, DWORD dwFlags, LPCWSTR lpWideCharStr, INT cchWideChar, LPSTR lpMultiByteStr, INT cchMultiByte, LPCSTR lpDefaultChar, LPBOOL lpUsedDefaultChar);
-BOOL WINAPI WriteConsoleA (HANDLE hConsoleOutput, CONST VOID *lpBuffer, DWORD nNumberOfCharsToWrite, LPDWORD lpNumberOfCharsWritten, LPVOID lpReserved);
-BOOL WINAPI WriteConsoleW (HANDLE hConsoleOutput, CONST VOID *lpBuffer, DWORD nNumberOfCharsToWrite, LPDWORD lpNumberOfCharsWritten, LPVOID lpReserved);
+BOOL WINAPI WriteConsoleA (HANDLE hConsoleOutput, LPCVOID lpBuffer, DWORD nNumberOfCharsToWrite, LPDWORD lpNumberOfCharsWritten, LPVOID lpReserved);
+BOOL WINAPI WriteConsoleW (HANDLE hConsoleOutput, LPCVOID lpBuffer, DWORD nNumberOfCharsToWrite, LPDWORD lpNumberOfCharsWritten, LPVOID lpReserved);
 BOOL WINAPI WriteFile (HANDLE hFile, LPCVOID lpBuffer, DWORD nNumberOfBytesToWrite, LPDWORD lpNumberOfBytesWritten, LPOVERLAPPED lpOverlapped);
 BOOL WINAPI WritePrivateProfileSectionA (LPCSTR lpAppName, LPCSTR lpString, LPCSTR lpFileName);
 BOOL WINAPI WritePrivateProfileSectionW (LPCWSTR lpAppName, LPCWSTR lpString, LPCWSTR lpFileName);
@@ -932,6 +1111,7 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 
 #ifdef UNICODE
 # define AddAtom AddAtomW
+# define CompareString CompareStringW
 # define CopyFile CopyFileW
 # define CreateDirectory CreateDirectoryW
 # define CreateEvent CreateEventW
@@ -957,6 +1137,8 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 # define GetEnvironmentStrings GetEnvironmentStringsW
 # define GetEnvironmentVariable GetEnvironmentVariableW
 # define GetFileAttributes GetFileAttributesW
+# define GetFullPathName GetFullPathNameW
+# define GetLocaleInfo GetLocaleInfoW
 # define GetLogicalDriveStrings GetLogicalDriveStringsW
 # define GetModuleFileName GetModuleFileNameW
 # define GetModuleHandle GetModuleHandleW
@@ -968,8 +1150,10 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 # define GetProfileSection GetProfileSectionW
 # define GetProfileString GetProfileStringW
 # define GetShortPathName GetShortPathNameW
+# define GetStartupInfo GetStartupInfoW
 # define GetStringType GetStringTypeW
 # define GetSystemDirectory GetSystemDirectoryW
+# define GetTempFileName GetTempFileNameW
 # define GetTempPath GetTempPathW
 # define GetVersionEx GetVersionExW
 # define GlobalAddAtom GlobalAddAtomW
@@ -987,6 +1171,7 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 # define OutputDebugString OutputDebugStringW
 # define RemoveDirectory RemoveDirectoryW
 # define SetCurrentDirectory SetCurrentDirectoryW
+# define SetEnvironmentVariable SetEnvironmentVariableW
 # define VerLanguageName VerLanguageNameW
 # define WriteConsole WriteConsoleW
 # define WritePrivateProfileSection WritePrivateProfileSectionW
@@ -1002,6 +1187,7 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 # define lstrlen lstrlenW
 #else /* not UNICODE*/
 # define AddAtom AddAtomA
+# define CompareString CompareStringA
 # define CopyFile CopyFileA
 # define CreateDirectory CreateDirectoryA
 # define CreateEvent CreateEventA
@@ -1027,6 +1213,8 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 # define GetEnvironmentStrings GetEnvironmentStringsA
 # define GetEnvironmentVariable GetEnvironmentVariableA
 # define GetFileAttributes GetFileAttributesA
+# define GetFullPathName GetFullPathNameA
+# define GetLocaleInfo GetLocaleInfoA
 # define GetLogicalDriveStrings GetLogicalDriveStringsA
 # define GetModuleFileName GetModuleFileNameA
 # define GetModuleHandle GetModuleHandleA
@@ -1038,8 +1226,10 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 # define GetProfileSection GetProfileSectionA
 # define GetProfileString GetProfileStringA
 # define GetShortPathName GetShortPathNameA
+# define GetStartupInfo GetStartupInfoA
 # define GetStringType GetStringTypeA
 # define GetSystemDirectory GetSystemDirectoryA
+# define GetTempFileName GetTempFileNameA
 # define GetTempPath GetTempPathA
 # define GetVersionEx GetVersionExA
 # define GlobalAddAtom GlobalAddAtomA
@@ -1057,6 +1247,7 @@ INT WINAPI lstrlenW (LPCWSTR lpString);
 # define OutputDebugString OutputDebugStringA
 # define RemoveDirectory RemoveDirectoryA
 # define SetCurrentDirectory SetCurrentDirectoryA
+# define SetEnvironmentVariable SetEnvironmentVariableA
 # define VerLanguageName VerLanguageNameA
 # define WriteConsole WriteConsoleA
 # define WritePrivateProfileSection WritePrivateProfileSectionA
