@@ -21,6 +21,11 @@
 
 #ifdef W32LDR_HEADER
 #include "pshpack1.h"
+#define S_OK 0
+#define S_FALSE 1
+#define E_FAIL 0x80004005
+#define CLASS_E_NOAGGREGATION 0x80040110L
+#define TYPE_E_LIBNOTREGISTERED 0x8002801d
 typedef struct _GUID
 {
   LONG Data1;
@@ -31,13 +36,13 @@ typedef struct _GUID
 #include "poppack.h"
 typedef LONG HRESULT;
 typedef VOID *LPUNKNOWN;
+typedef WCHAR OLECHAR;
 typedef LPWSTR LPOLESTR;
+typedef LPCWSTR LPCOLESTR;
 #define REFGUID  const GUID* const
 #define REFCLSID const CLSID* const
 #define REFIID   const IID* const
 #define REFFMTID const FMTID* const
-#define CLASS_E_NOAGGREGATION 0x80040110L
-#define S_FALSE ((HRESULT)1L)
 #endif /* W32LDR_HEADER */
 
 
