@@ -19,6 +19,18 @@
 #include "oleaut32.h"
 
 
+#ifdef W32LDR_HEADER
+#include "ole32.h"
+typedef struct _ITypeLib ITypeLib;
+typedef enum _REGKIND
+{
+  REGKIND_DEFAULT,
+  REGKIND_REGISTER,
+  REGKIND_NONE
+} REGKIND;
+#endif /* W32LDR_HEADER */
+
+
 /* BSTR_UserFree ordinal = 286, argument = 0 temporary */
 static DWORD WINAPI BSTR_UserFree (VOID)
 {
@@ -268,17 +280,17 @@ static DWORD WINAPI LoadRegTypeLib (VOID)
 }
 
 
-/* LoadTypeLib ordinal = 161, argument = 0 temporary */
-static DWORD WINAPI LoadTypeLib (VOID)
+/* LoadTypeLib ordinal = 161, argument = 0 */
+HRESULT WINAPI LoadTypeLib (LPCOLESTR szFile, ITypeLib **pptLib)
 {
-  return 0;
+  return LoadTypeLibEx (szFile, REGKIND_DEFAULT, pptLib);
 }
 
 
-/* LoadTypeLibEx ordinal = 183, argument = 0 temporary */
-static DWORD WINAPI LoadTypeLibEx (VOID)
+/* LoadTypeLibEx ordinal = 183, argument = 0 */
+HRESULT WINAPI LoadTypeLibEx (LPCOLESTR szFile, REGKIND regkind, ITypeLib **pptLib)
 {
-  return 0;
+  return TYPE_E_LIBNOTREGISTERED;
 }
 
 
@@ -394,10 +406,10 @@ static DWORD WINAPI RegisterActiveObject (VOID)
 }
 
 
-/* RegisterTypeLib ordinal = 163, argument = 0 temporary */
-static DWORD WINAPI RegisterTypeLib (VOID)
+/* RegisterTypeLib ordinal = 163, argument = 0 */
+HRESULT WINAPI RegisterTypeLib (ITypeLib *ptlib, OLECHAR *szFullPath, OLECHAR *szHelpDir)
 {
-  return 0;
+  return E_FAIL;
 }
 
 
@@ -2573,8 +2585,8 @@ W32LdrExport oleaut32_exports[] = {
 {FALSE, 291, "LPSAFEARRAY_UserSize",           LPSAFEARRAY_UserSize},
 {FALSE, 293, "LPSAFEARRAY_UserUnmarshal",      LPSAFEARRAY_UserUnmarshal},
 {FALSE, 162, "LoadRegTypeLib",                 LoadRegTypeLib},
-{FALSE, 161, "LoadTypeLib",                    LoadTypeLib},
-{FALSE, 183, "LoadTypeLibEx",                  LoadTypeLibEx},
+{TRUE,  161, "LoadTypeLib",                    LoadTypeLib},
+{TRUE,  183, "LoadTypeLibEx",                  LoadTypeLibEx},
 {FALSE, 144, "OACreateTypeLib2",               OACreateTypeLib2},
 {FALSE, 170, "OaBuildVersion",                 OaBuildVersion},
 {FALSE, 420, "OleCreateFontIndirect",          OleCreateFontIndirect},
@@ -2591,7 +2603,7 @@ W32LdrExport oleaut32_exports[] = {
 {FALSE, 421, "OleTranslateColor",              OleTranslateColor},
 {FALSE, 164, "QueryPathOfRegTypeLib",          QueryPathOfRegTypeLib},
 {FALSE,  33, "RegisterActiveObject",           RegisterActiveObject},
-{FALSE, 163, "RegisterTypeLib",                RegisterTypeLib},
+{TRUE,  163, "RegisterTypeLib",                RegisterTypeLib},
 {FALSE,  34, "RevokeActiveObject",             RevokeActiveObject},
 {FALSE,  23, "SafeArrayAccessData",            SafeArrayAccessData},
 {FALSE,  37, "SafeArrayAllocData",             SafeArrayAllocData},
