@@ -1,6 +1,6 @@
 /*
     w32loader
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,9 +28,24 @@ extern "C" {
 #endif /* __cplusplus */
 
 
+#include "ole32.h"
+typedef struct _ITypeLib ITypeLib;
+typedef enum _REGKIND
+{
+  REGKIND_DEFAULT,
+  REGKIND_REGISTER,
+  REGKIND_NONE
+} REGKIND;
+
+
 extern W32LdrExport oleaut32_exports[];
 
 
+HRESULT WINAPI LoadTypeLib (LPCOLESTR szFile, ITypeLib **pptLib);
+HRESULT WINAPI LoadTypeLibEx (LPCOLESTR szFile, REGKIND regkind, ITypeLib **pptLib);
+HRESULT WINAPI RegisterTypeLib (ITypeLib *ptlib, OLECHAR *szFullPath, OLECHAR *szHelpDir);
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
