@@ -27,11 +27,10 @@
 
 typedef struct _W32LdrDrop *HDROP;
 
-#define S_OK 0
 #ifndef NOERROR
 # define NOERROR 0
 #endif /* not NOERROR */
-#define E_FAIL 0x80004005
+
 typedef struct _IMalloc IMalloc, *LPMALLOC;
 #include "pshpack1.h"
 typedef struct _IMallocVtbl
