@@ -279,6 +279,18 @@ extern "C" {
 typedef VOID CALLBACK (*TIMERPROC)(HWND, UINT, UINT, DWORD);
 
 /* ja:描画 */
+#define RDW_INVALIDATE      0x0001
+#define RDW_INTERNALPAINT   0x0002
+#define RDW_ERASE           0x0004
+#define RDW_VALIDATE        0x0008
+#define RDW_NOINTERNALPAINT 0x0010
+#define RDW_NOERASE         0x0020
+#define RDW_NOCHILDREN      0x0040
+#define RDW_ALLCHILDREN     0x0080
+#define RDW_UPDATENOW       0x0100
+#define RDW_ERASENOW        0x0200
+#define RDW_FRAME           0x0400
+#define RDW_NOFRAME         0x0800
 #include "pshpack1.h"
 typedef struct _POINT
 {
@@ -293,6 +305,7 @@ typedef struct _RECT
   LONG bottom;
 } RECT, *PRECT, *LPRECT;
 typedef const RECT *LPCRECT;
+typedef GdkRegion *HRGN;
 typedef struct _PAINTSTRUCT
 {
   HDC hdc;
@@ -1008,6 +1021,8 @@ HWND WINAPI GetDesktopWindow (VOID);
 INT WINAPI GetDlgCtrlID (HWND hWndCtl);
 HWND WINAPI GetDlgItem (HWND hDlg, INT nIDDlgItem);
 UINT WINAPI GetDlgItemInt (HWND hDlg, INT nIDDlgItem, BOOL *lpTranslated, BOOL bSigned);
+UINT WINAPI GetDlgItemTextA (HWND hDlg, INT nIDDlgItem, LPSTR lpString, INT nMaxCount);
+UINT WINAPI GetDlgItemTextW (HWND hDlg, INT nIDDlgItem, LPWSTR lpString, INT nMaxCount);
 HWND WINAPI GetFocus (VOID);
 INT WINAPI GetKeyboardType (INT nTypeFlag);
 HMENU WINAPI GetMenu (HWND hWnd);
@@ -1087,6 +1102,7 @@ BOOL WINAPI PostMessageA (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
 BOOL WINAPI PostMessageW (HWND hWnd, UINT Msg, WPARAM wParam, LPARAM lParam);
 VOID WINAPI PostQuitMessage (INT nExitCode);
 BOOL WINAPI PtInRect (CONST LPRECT lprc, POINT pt);
+BOOL WINAPI RedrawWindow (HWND hWnd, LPCRECT lprcUpdate, HRGN hrgnUpdate, UINT flags);
 ATOM WINAPI RegisterClassA (CONST LPWNDCLASSA lpWndClass);
 ATOM WINAPI RegisterClassExA (CONST LPWNDCLASSEXA lpWndClassEx);
 ATOM WINAPI RegisterClassExW (CONST LPWNDCLASSEXW lpWndClassEx);
@@ -1158,6 +1174,7 @@ INT WINAPI wvsprintfW (LPSTR lpOutput, LPCSTR lpFormat, va_list arglist);
 # define DialogBoxParam DialogBoxParamW
 # define DispatchMessage DispatchMessageW
 # define GetClassName GetClassNameW
+# define GetDlgItemText GetDlgItemTextW
 # define GetMenuItemInfo GetMenuItemInfoW
 # define GetMenuString GetMenuStringW
 # define GetMessage GetMessageW
@@ -1206,6 +1223,7 @@ INT WINAPI wvsprintfW (LPSTR lpOutput, LPCSTR lpFormat, va_list arglist);
 # define DialogBoxParam DialogBoxParamA
 # define DispatchMessage DispatchMessageA
 # define GetClassName GetClassNameA
+# define GetDlgItemText GetDlgItemTextA
 # define GetMenuItemInfo GetMenuItemInfoA
 # define GetMenuString GetMenuStringA
 # define GetMessage GetMessageA
