@@ -24,6 +24,7 @@
 #include "gdi32.h"
 #include "kernel32.h"
 #include "msvcrt.h"
+#include "ntdll.h"
 #include "ole32.h"
 #include "oleaut32.h"
 #include "rasapi32.h"
@@ -235,6 +236,7 @@ w32ldr_module_load_library (const gchar    *file,
     {"gdi32.dll",    gdi32_exports},
     {"kernel32.dll", kernel32_exports},
     {"msvcrt.dll",   msvcrt_exports},
+    {"ntdll.dll",    ntdll_exports},
     {"ole32.dll",    ole32_exports},
     {"oleaut32.dll", oleaut32_exports},
     {"rasapi32.dll", rasapi32_exports},
@@ -295,15 +297,19 @@ w32ldr_module_load_library (const gchar    *file,
   for (i = 0; i < 8; i++)
     if (!image)
       {
+        gchar *path;
+
         g_free (module->name);
         g_free (module->file);
         module->name = i % 2 == 0 ? g_path_get_basename (file)
                                   : w32ldr_module_get_basename (file);
-        module->file = i < 4 ? g_build_filename (w32ldr_dir_get_path
+        path = i < 4 ? g_build_filename (w32ldr_dir_get_path
                         (i / 2 == 0 ? W32LDR_DIR_SYSTEM : W32LDR_DIR_WINDOWS),
                                                         module->name, NULL)
                     : g_build_filename (w32ldr_dir_get_path (W32LDR_DIR_HOME),
                                     i < 6 ? "bin" : "lib", module->name, NULL);
+        module->file = w32ldr_dir_get_case_insensitive (path);
+        g_free (path);
         image = fileio_load (module->file, &length);
       }
   if (!image || length < 0x40 || *(guint16 *)image != IMAGE_DOS_SIGNATURE
@@ -412,6 +418,7 @@ w32ldr_module_load_library (const gchar    *file,
                   PIMAGE_IMPORT_BY_NAME piibn;
 #ifdef USE_DEBUG
                   const static gchar *fmt = "%s\n";
+                  gchar *str;
                   gsize leng;
                   guint8 *opcode, *p;
 #endif /* USE_DEBUG */
@@ -422,28 +429,31 @@ w32ldr_module_load_library (const gchar    *file,
                   func = piat[j].u1.Ordinal & IMAGE_ORDINAL_FLAG
                         ? w32ldr_module_get_proc (mod, ordinal)
                         : w32ldr_module_get_func (mod, (gchar *)piibn->Name);
+#ifdef USE_DEBUG
+                  str = piat[j].u1.Ordinal & IMAGE_ORDINAL_FLAG
+                    ? g_strdup_printf ("%s,%d", image + piid[i].Name, ordinal)
+                    : g_strdup_printf ("%s,%s", image + piid[i].Name,
+                                                                piibn->Name);
+
+#endif /* USE_DEBUG */
                   if (!func)
                     {
                       const static guint8 ret_code = 0xc3;
 
 #ifdef USE_DEBUG
-                      if (piat[j].u1.Ordinal & IMAGE_ORDINAL_FLAG)
-                        g_warning ("import-function:%s,%d\n",
-                                                image + piid[i].Name, ordinal);
-                      else
-                        g_warning ("import-function:%s\n", piibn->Name);
+                      g_warning ("import-function:%s\n", str);
 #endif /* USE_DEBUG */
                       func = (gpointer)&ret_code;
                       result = FALSE;
                     }
 #ifdef USE_DEBUG
-                  leng = g_strlen ((gchar *)piibn->Name) + 1;
+                  leng = g_strlen (str) + 1;
                   p = opcode = g_malloc (leng + 26);
                   *p++ = 0x60;
                   *p++ = 0xe8;
                   *(guint32 *)p = leng;
                   p += 4;
-                  g_strcpy ((gchar *)p, (gchar *)piibn->Name);
+                  g_strcpy ((gchar *)p, str);
                   p += leng;
                   *p++ = 0x68;
                   *(guint32 *)p = GPOINTER_TO_UINT (fmt);
@@ -460,6 +470,7 @@ w32ldr_module_load_library (const gchar    *file,
                   *(guint32 *)p = GPOINTER_TO_UINT (func)
                                                 - (GPOINTER_TO_INT (p) + 4);
                   pilt[j].u1.Function = GPOINTER_TO_UINT (opcode);
+                  g_free (str);
 #else /* not USE_DEBUG */
                   pilt[j].u1.Function = GPOINTER_TO_UINT (func);
 #endif /* not USE_DEBUG */
