@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#ifndef __W32USER_H__
-#define __W32USER_H__
+#ifndef __W32PRIVATE_H__
+#define __W32PRIVATE_H__
 
 
 #include "user32.h"
@@ -32,8 +32,10 @@ extern "C" {
 typedef struct _W32LdrClassData
 {
   WNDPROC lpfnWndProc;
+  HINSTANCE hInstance;
   gboolean widechar;
   gchar *classname;
+  gchar *menuname;
   guint16 atom;
 } W32LdrClassData;
 typedef struct _W32LdrWindowData
@@ -62,6 +64,7 @@ typedef struct _W32LdrOverlapData
   W32LdrWindowData wd;
   GtkWidget *table;
   GtkWidget *fixed;
+  GtkWidget *menu;
   GtkWidget *hscroll;
   GtkWidget *vscroll;
 } W32LdrOverlapData;
@@ -75,9 +78,6 @@ typedef struct _W32LdrPageData
 } W32LdrPageData;
 
 
-extern GHashTable *ghash_class;
-
-
 /******************************************************************************
 *                                                                             *
 * ja:プロトタイプ宣言                                                         *
@@ -244,6 +244,9 @@ w32ldr_control_create_updwn (const gchar    *windowname,
 * ja:クラス関数群                                                             *
 *                                                                             *
 ******************************************************************************/
+extern GHashTable *ghash_class;
+
+
 ATOM
 w32ldr_RegisterClassEx (UINT            style,
                         WNDPROC         lpfnWndProc,
@@ -270,6 +273,7 @@ w32ldr_CreateDialogIndirectParam (HINSTANCE      hInstance,
                                   HWND           hWndParent,
                                   DLGPROC        lpDialogFunc,
                                   LPARAM         dwInitParam,
+                                  const gboolean modal,
                                   const gboolean widechar);
 
 
@@ -290,6 +294,40 @@ gchar *
 w32ldr_dialog_get_title (LPCDLGTEMPLATE lpDialogTemplate);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:メニュー関数群                                                           *
+*                                                                             *
+******************************************************************************/
+HMENU
+w32ldr_LoadMenuIndirect (HINSTANCE       hInstance,
+                         LPCMENUTEMPLATE lpMenuTemplate);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:メニューサポート関数群                                                   *
+*                                                                             *
+******************************************************************************/
+GdkPixbuf *
+w32ldr_menu_get_pixbuf_check (void);
+
+
+GdkPixbuf *
+w32ldr_menu_get_pixbuf_radio (void);
+
+
+gint
+w32ldr_menu_get_item_pos (GtkWidget   *menu,
+                          const guint  item);
+
+
+GtkWidget *
+w32ldr_menu_get_item (GtkWidget   *menu,
+                      const gint   pos,
+                      const guint  flags);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ウインドウ関数群                                                         *
@@ -316,4 +354,4 @@ w32ldr_CreateWindowEx (DWORD           dwExStyle,
 #endif /* __cplusplus */
 
 
-#endif /* __W32USER_H__ */
+#endif /* __W32PRIVATE_H__ */
