@@ -64,7 +64,8 @@ w32prsht_DefWindowProc (HWND   hWnd,
 #endif /* not GTK_CHECK_VERSION(2,2,0) */
           if (0 <= page && page < n_pages)
             {
-              gtk_notebook_set_current_page (GTK_NOTEBOOK (nd->notebook), page);
+              gtk_notebook_set_current_page (GTK_NOTEBOOK (nd->notebook),
+                                                                        page);
               return TRUE;
             }
         }
@@ -272,10 +273,11 @@ w32prsht_DefWindowProc (HWND   hWnd,
           {
             gchar *utf8str;
 
-            utf8str = Msg ==  PSM_SETFINISHTEXTA
+            utf8str = lParam ? Msg ==  PSM_SETFINISHTEXTA
                             ? w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
                             : g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
-                                                        -1, NULL, NULL, NULL);
+                                                        -1, NULL, NULL, NULL)
+                            : g_strdup ("");
             gtk_button_set_label (GTK_BUTTON (nd->button_finish), utf8str);
             g_free (utf8str);
           }
@@ -336,8 +338,8 @@ w32prsht_clicked_current (GtkWidget *widget,
 
 /* ja:ボタンが押されたとき */
 static void
-w32prsht_clicked_all (GtkWidget *widget,
-                      GtkWidget *prsht)
+w32prsht_clicked_apply (GtkWidget *widget,
+                        GtkWidget *prsht)
 {
   gint i;
   GtkWidget *child;
@@ -349,8 +351,7 @@ w32prsht_clicked_all (GtkWidget *widget,
   wd = &nd->wd;
   nmh.hwndFrom = prsht;
   nmh.idFrom = wd->wID;
-  nmh.code = GPOINTER_TO_UINT (g_object_get_data
-                                            (G_OBJECT (widget), "user_data"));
+  nmh.code = PSN_APPLY;
   for (i = 0; (child = gtk_notebook_get_nth_page
                                         (GTK_NOTEBOOK (nd->notebook), i)); i++)
     if (wd->widechar)
@@ -360,6 +361,82 @@ w32prsht_clicked_all (GtkWidget *widget,
 }
 
 
+/* ja:ボタンが押されたとき */
+static void
+w32prsht_clicked_ok (GtkWidget *widget,
+                     GtkWidget *prsht)
+{
+  gint i;
+  GtkWidget *child;
+  NMHDR nmh;
+  W32LdrWindowData *wd;
+  W32LdrNoteData *nd;
+
+  nd = g_object_get_data (G_OBJECT (prsht), "user_data");
+  wd = &nd->wd;
+  nmh.hwndFrom = prsht;
+  nmh.idFrom = wd->wID;
+  nmh.code = PSN_APPLY;
+  for (i = 0; (child = gtk_notebook_get_nth_page
+                                        (GTK_NOTEBOOK (nd->notebook), i)); i++)
+    if (wd->widechar)
+      SendMessageW (child, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
+    else
+      SendMessageA (child, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
+  if (GTK_IS_DIALOG (prsht))
+    gtk_dialog_response (GTK_DIALOG (prsht), GTK_RESPONSE_OK);
+}
+
+
+/* ja:ボタンが押されたとき */
+static void
+w32prsht_clicked_cancel (GtkWidget *widget,
+                         GtkWidget *prsht)
+{
+  gint i;
+  GtkWidget *child;
+  NMHDR nmh;
+  W32LdrWindowData *wd;
+  W32LdrNoteData *nd;
+
+  nd = g_object_get_data (G_OBJECT (prsht), "user_data");
+  wd = &nd->wd;
+  nmh.hwndFrom = prsht;
+  nmh.idFrom = wd->wID;
+  nmh.code = PSN_QUERYCANCEL;
+  for (i = 0; (child = gtk_notebook_get_nth_page
+                                        (GTK_NOTEBOOK (nd->notebook), i)); i++)
+    if (wd->widechar ? SendMessageW (child, WM_NOTIFY,
+                                            wd->wID, GPOINTER_TO_INT (&nmh))
+                     : SendMessageA (child, WM_NOTIFY,
+                                            wd->wID, GPOINTER_TO_INT (&nmh)))
+      return;
+  nmh.code = PSN_RESET;
+  for (i = 0; (child = gtk_notebook_get_nth_page
+                                        (GTK_NOTEBOOK (nd->notebook), i)); i++)
+    if (wd->widechar)
+      SendMessageW (child, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
+    else
+      SendMessageA (child, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
+  if (GTK_IS_DIALOG (prsht))
+    gtk_dialog_response (GTK_DIALOG (prsht), GTK_RESPONSE_CANCEL);
+}
+
+
+/* ja:閉じるボタンが押されたとき */
+static gboolean
+w32prsht_delete_event (GtkWidget *widget,
+                       GdkEvent  *event,
+                       gpointer   user_data)
+{
+  W32LdrNoteData *nd;
+
+  nd = g_object_get_data (G_OBJECT (widget), "user_data");
+  w32prsht_clicked_cancel (nd->button_cancel, widget);
+  return TRUE;
+}
+
+
 /* ja:ページが切り替わったとき */
 static void
 w32prsht_switch_page (GtkNotebook     *notebook,
@@ -387,97 +464,6 @@ w32prsht_switch_page (GtkNotebook     *notebook,
 }
 
 
-/* ja:破棄 */
-static void
-w32prsht_destroy (GtkWidget *widget,
-                  gpointer   user_data)
-{
-  gint i;
-  GtkWidget *child;
-  NMHDR nmh;
-  W32LdrWindowData *wd;
-  W32LdrNoteData *nd;
-
-  nd = g_object_get_data (G_OBJECT (widget), "user_data");
-  wd = &nd->wd;
-  nmh.hwndFrom = widget;
-  nmh.idFrom = wd->wID;
-  nmh.code = PSN_RESET;
-  for (i = 0; (child = gtk_notebook_get_nth_page
-                                        (GTK_NOTEBOOK (nd->notebook), i)); i++)
-    if (wd->widechar)
-      SendMessageW (child, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
-    else
-      SendMessageA (child, WM_NOTIFY, wd->wID, GPOINTER_TO_INT (&nmh));
-}
-
-
-/* ja:ボタンが押されたとき */
-static void
-w32prsht_cancel_clicked (GtkWidget *widget,
-                         GtkWidget *prsht)
-{
-  gint i;
-  GtkWidget *child;
-  NMHDR nmh;
-  W32LdrWindowData *wd;
-  W32LdrNoteData *nd;
-
-  nd = g_object_get_data (G_OBJECT (prsht), "user_data");
-  wd = &nd->wd;
-  nmh.hwndFrom = prsht;
-  nmh.idFrom = wd->wID;
-  nmh.code = PSN_QUERYCANCEL;
-  for (i = 0; (child = gtk_notebook_get_nth_page
-                                        (GTK_NOTEBOOK (nd->notebook), i)); i++)
-    if (wd->widechar ? SendMessageW (child, WM_NOTIFY,
-                                            wd->wID, GPOINTER_TO_INT (&nmh))
-                     : SendMessageA (child, WM_NOTIFY,
-                                            wd->wID, GPOINTER_TO_INT (&nmh)))
-      break;
-  if (!child)
-    {
-      g_signal_connect (G_OBJECT (prsht), "destroy",
-                                        G_CALLBACK (w32prsht_destroy), NULL);
-      gtk_widget_destroy (prsht);
-    }
-}
-
-
-/* ja:閉じるボタンが押されたとき */
-static gboolean
-w32prsht_delete_event (GtkWidget *widget,
-                       GdkEvent  *event,
-                       gpointer   user_data)
-{
-  gboolean result = FALSE;
-  gint i;
-  GtkWidget *child;
-  NMHDR nmh;
-  W32LdrWindowData *wd;
-  W32LdrNoteData *nd;
-
-  nd = g_object_get_data (G_OBJECT (widget), "user_data");
-  wd = &nd->wd;
-  nmh.hwndFrom = widget;
-  nmh.idFrom = wd->wID;
-  nmh.code = PSN_QUERYCANCEL;
-  for (i = 0; (child = gtk_notebook_get_nth_page
-                                        (GTK_NOTEBOOK (nd->notebook), i)); i++)
-    if (wd->widechar ? SendMessageW (child, WM_NOTIFY,
-                                            wd->wID, GPOINTER_TO_INT (&nmh))
-                     : SendMessageA (child, WM_NOTIFY,
-                                            wd->wID, GPOINTER_TO_INT (&nmh)))
-      break;
-  if (child)
-    result = TRUE;
-  else
-    g_signal_connect (G_OBJECT (widget), "destroy",
-                                        G_CALLBACK (w32prsht_destroy), NULL);
-  return result;
-}
-
-
 GtkWidget *
 w32ldr_control_create_prsht (const gchar    *windowname,
                              const guint32   style,
@@ -490,31 +476,44 @@ w32ldr_control_create_prsht (const gchar    *windowname,
                              const gboolean  widechar)
 {
   gchar *title;
-  GtkWidget *prsht, *notebook, *hbox, *button_cancel, *button_help;
+  GtkWidget *prsht, *notebook, *hbox, *vbox, *button_cancel, *button_help;
   GtkWidget *button_apply, *button_ok, *button_close;
   GtkWidget *button_back, *button_next, *button_finish;
   W32LdrNoteData *nd;
   W32LdrWindowData *wd;
 
   /* ja:ダイアログ */
-  prsht = gtk_dialog_new ();
+  if (style & PSH_MODELESS)
+    {
+      prsht = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+      vbox = gtk_vbox_new (FALSE, SPACING);
+      gtk_widget_show (vbox);
+      gtk_container_add (GTK_CONTAINER (prsht), vbox);
+    }
+  else
+    {
+      prsht = gtk_dialog_new ();
+      gtk_dialog_set_has_separator (GTK_DIALOG (prsht), FALSE);
+      gtk_widget_hide (GTK_DIALOG (prsht)->action_area);
+      vbox = GTK_DIALOG (prsht)->vbox;
+    }
   title = w32ldr_atom_get_string (windowname);
   if (title)
     {
       gtk_window_set_title (GTK_WINDOW (prsht), title);
       g_free (title);
     }
-  gtk_dialog_set_has_separator (GTK_DIALOG (prsht), FALSE);
   g_signal_connect (G_OBJECT (prsht), "delete-event",
                                     G_CALLBACK (w32prsht_delete_event), NULL);
   /* ja:ノートブック */
   notebook = gtk_notebook_new ();
-  g_signal_connect (G_OBJECT (prsht), "switch-page",
-                                    G_CALLBACK (w32prsht_switch_page), NULL);
+  g_signal_connect (G_OBJECT (notebook), "switch-page",
+                                    G_CALLBACK (w32prsht_switch_page), prsht);
   gtk_widget_show (notebook);
   /* ja:ボタン */
   hbox = gtk_hbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), SPACING);
+  gtk_widget_show (hbox);
   if (style & PSH_HASHELP)
     {
       button_help = gtk_button_new_from_stock (GTK_STOCK_HELP);
@@ -530,10 +529,8 @@ w32ldr_control_create_prsht (const gchar    *windowname,
       button_help = NULL;
     }
   button_cancel = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-  g_object_set_data (G_OBJECT (button_cancel), "user_data",
-                                        GUINT_TO_POINTER (PSN_QUERYCANCEL));
   g_signal_connect (G_OBJECT (button_cancel), "clicked",
-                                G_CALLBACK (w32prsht_cancel_clicked), prsht);
+                                G_CALLBACK (w32prsht_clicked_cancel), prsht);
   gtk_widget_show (button_cancel);
   if (style & PSH_WIZARD)
     {
@@ -567,38 +564,34 @@ w32ldr_control_create_prsht (const gchar    *windowname,
     }
   else
     {
-      button_apply = style & PSH_NOAPPLYNOW
-                        ? gtk_button_new_from_stock (GTK_STOCK_APPLY) : NULL;
       button_ok = gtk_button_new_from_stock (GTK_STOCK_OK);
       button_close = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
       button_back = button_next = button_finish = NULL;
-      g_object_set_data (G_OBJECT (button_apply), "user_data",
-                                                GUINT_TO_POINTER (PSN_APPLY));
-      g_object_set_data (G_OBJECT (button_ok), "user_data",
-                                                GUINT_TO_POINTER (PSN_APPLY));
-      g_object_set_data (G_OBJECT (button_close), "user_data",
-                                                GUINT_TO_POINTER (PSN_APPLY));
-      g_signal_connect (G_OBJECT (button_apply), "clicked",
-                                    G_CALLBACK (w32prsht_clicked_all), prsht);
       g_signal_connect (G_OBJECT (button_ok), "clicked",
-                                    G_CALLBACK (w32prsht_clicked_all), prsht);
+                                    G_CALLBACK (w32prsht_clicked_ok), prsht);
       g_signal_connect (G_OBJECT (button_close), "clicked",
-                                    G_CALLBACK (w32prsht_clicked_all), prsht);
+                                    G_CALLBACK (w32prsht_clicked_ok), prsht);
       gtk_box_pack_end (GTK_BOX (hbox), button_close, FALSE, FALSE, 0);
       gtk_box_pack_end (GTK_BOX (hbox), button_ok, FALSE, FALSE, 0);
       gtk_box_pack_end (GTK_BOX (hbox), button_cancel, FALSE, FALSE, 0);
-      if (button_apply)
+      gtk_widget_show (button_ok);
+      if (style & PSH_NOAPPLYNOW)
         {
+          button_apply = gtk_button_new_from_stock (GTK_STOCK_APPLY);
+          g_signal_connect (G_OBJECT (button_apply), "clicked",
+                                G_CALLBACK (w32prsht_clicked_apply), prsht);
           gtk_box_pack_end (GTK_BOX (hbox), button_apply, FALSE, FALSE, 0);
           gtk_widget_show (button_apply);
           gtk_widget_set_sensitive (button_apply, FALSE);
         }
-      gtk_widget_show (button_ok);
+      else
+        {
+          button_apply = NULL;
+        }
     }
   /* ja:フレームとボックス */
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (prsht)->vbox),
-                                                    notebook, TRUE, TRUE, 0);
-  gtk_box_pack_end (GTK_BOX (GTK_DIALOG (prsht)->vbox), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
+  gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   gtk_window_set_destroy_with_parent (GTK_WINDOW (prsht), TRUE);
   gtk_window_set_position (GTK_WINDOW (prsht), GTK_WIN_POS_CENTER_ON_PARENT);
   nd = g_malloc (sizeof (W32LdrNoteData));
