@@ -382,7 +382,7 @@ w32tool_DefWindowProc (HWND   hWnd,
                           }
                       }
                     if (lptbab->hInst)
-                      g_object_unref (pixbuf);
+                      g_object_unref (G_OBJECT (pixbuf));
                   }
               }
             return lResult;
@@ -826,7 +826,7 @@ w32tool_destroy (GtkWidget *widget,
   td = g_object_get_data (G_OBJECT (widget), "user_data");
   for (glist = g_list_first (td->glist_pixbuf); glist;
                                                 glist = g_list_next (glist))
-    g_object_unref (glist->data);
+    g_object_unref (G_OBJECT (glist->data));
   g_list_free (td->glist_pixbuf);
   for (glist = g_list_first (td->glist_string); glist;
                                                 glist = g_list_next (glist))
