@@ -1,6 +1,6 @@
 /*
     w32loader
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,8 +21,10 @@
 
 
 #include "advapi32.h"
+#include "commdlg.h"
 #include "gdi32.h"
 #include "kernel32.h"
+#include "msvcrt.h"
 #include "ole32.h"
 #include "oleaut32.h"
 #include "shell32.h"
@@ -30,6 +32,7 @@
 #include "user32.h"
 #include "version.h"
 #include "winmm.h"
+#include "winsock.h"
 
 
 #endif /* __WINDOWS_H__ */
